==> rechn_mgm_user_area-0.1.3.gem: app/controllers/rechn_mgm_user_area/organisations_controller.rb <==
require_dependency "rechn_mgm_user_area/application_controller"

module RechnMgmUserArea
    class OrganisationsController < ApplicationController
        def new_invitation
            respond_to do |format|
                format.html
                format.js
            end
        end

        def create_invitation
            invited_user = DeviseAuthentication::User.where(email: organisation_params[:email]).first

            if invited_user.present?
                if invited_user.id == current_user.id
                    flash[:error] = "You cannot add yourself!"
                    redirect_to user_root_path
                    return
                end

                if current_user.user_ids_of_my_organisation.include? invited_user.id
                    flash[:error] = "This user is already in your organisation!"
                    redirect_to user_root_path
                    return
                end

                # User is already known: Add him directly
                success = current_user.add_user_to_my_organisation(invited_user.id)
                if success
                    flash[:info] = "The invited user was added."
                else
                    flash[:error] = "The invited user could not be added. Please contact administrator!"
                end
            else
                # User is not known: Invite him
                flash[:info] = "The invitation mail is sent to: #{organisation_params[:email]}"
                DeviseAuthentication::User.invite!({email: organisation_params[:email], forename: organisation_params[:first_name], lastname: organisation_params[:last_name]}, current_user)
            end
            redirect_to user_root_path
        end

        private
        def organisation_params
            params.require(:invitation).permit(:email, :first_name, :last_name)
        end
    end
end

==> rechn_mgm_user_area-0.1.11.gem: app/controllers/rechn_mgm_user_area/organisations_controller.rb <==
require_dependency "rechn_mgm_user_area/application_controller"

module RechnMgmUserArea
    class OrganisationsController < AuthenticatedController
        def new_invitation
            respond_to do |format|
                format.html
                format.js
            end
        end

        def create_invitation
            invited_user = DeviseAuthentication::User.where(email: organisation_params[:email]).first

            if invited_user.present?
                if invited_user.id == current_user.id
                    flash[:error] = "You cannot add yourself!"
                    redirect_to user_root_path
                    return
                end

                if current_user.user_ids_of_current_organisation.include? invited_user.id
                    flash[:error] = "This user is already in your organisation!"
                    redirect_to user_root_path
                    return
                end

                # User is already known: Add him directly
                success = current_user.add_user_to_my_organisation(invited_user.id)
                if success
                    flash[:info] = "The invited user was added."
                else
                    flash[:error] = "The invited user could not be added. Please contact administrator!"
                end
            else
                # User is not known: Invite him
                flash[:info] = "The invitation mail is sent to: #{organisation_params[:email]}"
                DeviseAuthentication::User.invite!({email: organisation_params[:email], forename: organisation_params[:first_name], lastname: organisation_params[:last_name]}, current_user)
            end
            redirect_to user_root_path
        end

        private
        def organisation_params
            params.require(:invitation).permit(:email, :first_name, :last_name)
        end
    end
end
